"""
Mango Python Library
"""
from resources import Charge as Charges
from resources import Refund as Refunds
from resources import Customer as Customers
from resources import Card as Cards
from resources import Queue
from resources import Installment as Installments
from resources import Promotion as Promotions
from resources import Coupon as Coupons

api_key = ""
version = 1
